==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/CallCenterDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CALENDARGROUPID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CALENDARGROUPID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PENALTYFACTOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PENALTYAMOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SDMFLAG" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "calendargroupid",
    "penaltyfactor",
    "penaltyamount",
    "sdmflag"
})
@XmlRootElement(name = "CallCenterDetails")
public class CallCenterDetails {

    @XmlElement(name = "CALENDARGROUPID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CALENDARGROUPID_Type calendargroupid;
    @XmlElement(name = "PENALTYFACTOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY penaltyfactor;
    @XmlElement(name = "PENALTYAMOUNT", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT penaltyamount;
    @XmlElement(name = "SDMFLAG", namespace = "http://schemas.datastream.net/MP_fields")
    protected String sdmflag;

    /**
     * Obtient la valeur de la propriété calendargroupid.
     * 
     * @return
     *     possible object is
     *     {@link CALENDARGROUPID_Type }
     *     
     */
    public CALENDARGROUPID_Type getCALENDARGROUPID() {
        return calendargroupid;
    }

    /**
     * Définit la valeur de la propriété calendargroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link CALENDARGROUPID_Type }
     *     
     */
    public void setCALENDARGROUPID(CALENDARGROUPID_Type value) {
        this.calendargroupid = value;
    }

    /**
     * Obtient la valeur de la propriété penaltyfactor.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPENALTYFACTOR() {
        return penaltyfactor;
    }

    /**
     * Définit la valeur de la propriété penaltyfactor.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPENALTYFACTOR(QUANTITY value) {
        this.penaltyfactor = value;
    }

    /**
     * Obtient la valeur de la propriété penaltyamount.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getPENALTYAMOUNT() {
        return penaltyamount;
    }

    /**
     * Définit la valeur de la propriété penaltyamount.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setPENALTYAMOUNT(AMOUNT value) {
        this.penaltyamount = value;
    }

    /**
     * Obtient la valeur de la propriété sdmflag.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSDMFLAG() {
        return sdmflag;
    }

    /**
     * Définit la valeur de la propriété sdmflag.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSDMFLAG(String value) {
        this.sdmflag = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/CallCenterDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CALENDARGROUPID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CALENDARGROUPID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PENALTYFACTOR" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PENALTYAMOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SDMFLAG" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "calendargroupid",
    "penaltyfactor",
    "penaltyamount",
    "sdmflag"
})
@XmlRootElement(name = "CallCenterDetails")
public class CallCenterDetails {

    @XmlElement(name = "CALENDARGROUPID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CALENDARGROUPID_Type calendargroupid;
    @XmlElement(name = "PENALTYFACTOR", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY penaltyfactor;
    @XmlElement(name = "PENALTYAMOUNT", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT penaltyamount;
    @XmlElement(name = "SDMFLAG", namespace = "http://schemas.datastream.net/MP_fields")
    protected String sdmflag;

    /**
     * Gets the value of the calendargroupid property.
     * 
     * @return
     *     possible object is
     *     {@link CALENDARGROUPID_Type }
     *     
     */
    public CALENDARGROUPID_Type getCALENDARGROUPID() {
        return calendargroupid;
    }

    /**
     * Sets the value of the calendargroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CALENDARGROUPID_Type }
     *     
     */
    public void setCALENDARGROUPID(CALENDARGROUPID_Type value) {
        this.calendargroupid = value;
    }

    /**
     * Gets the value of the penaltyfactor property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPENALTYFACTOR() {
        return penaltyfactor;
    }

    /**
     * Sets the value of the penaltyfactor property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPENALTYFACTOR(QUANTITY value) {
        this.penaltyfactor = value;
    }

    /**
     * Gets the value of the penaltyamount property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getPENALTYAMOUNT() {
        return penaltyamount;
    }

    /**
     * Sets the value of the penaltyamount property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setPENALTYAMOUNT(AMOUNT value) {
        this.penaltyamount = value;
    }

    /**
     * Gets the value of the sdmflag property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSDMFLAG() {
        return sdmflag;
    }

    /**
     * Sets the value of the sdmflag property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSDMFLAG(String value) {
        this.sdmflag = value;
    }

}
